# WorkItemChangedFieldsViewModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | [**StringWorkItemChangedFieldViewModel**](StringWorkItemChangedFieldViewModel.md) |  | [optional] 
**is_deleted** | [**BooleanWorkItemChangedFieldViewModel**](BooleanWorkItemChangedFieldViewModel.md) |  | [optional] 
**project_id** | [**GuidWorkItemChangedFieldViewModel**](GuidWorkItemChangedFieldViewModel.md) |  | [optional] 
**is_automated** | [**BooleanWorkItemChangedFieldViewModel**](BooleanWorkItemChangedFieldViewModel.md) |  | [optional] 
**section_id** | [**GuidWorkItemChangedFieldViewModel**](GuidWorkItemChangedFieldViewModel.md) |  | [optional] 
**description** | [**StringWorkItemChangedFieldViewModel**](StringWorkItemChangedFieldViewModel.md) |  | [optional] 
**state** | [**StringWorkItemChangedFieldViewModel**](StringWorkItemChangedFieldViewModel.md) |  | [optional] 
**priority** | [**StringWorkItemChangedFieldViewModel**](StringWorkItemChangedFieldViewModel.md) |  | [optional] 
**duration** | [**Int32WorkItemChangedFieldViewModel**](Int32WorkItemChangedFieldViewModel.md) |  | [optional] 
**attributes** | [**{str: (WorkItemChangedAttributeViewModel,)}, none_type**](WorkItemChangedAttributeViewModel.md) |  | [optional] 
**steps** | [**WorkItemStepChangeViewModelArrayWorkItemChangedFieldViewModel**](WorkItemStepChangeViewModelArrayWorkItemChangedFieldViewModel.md) |  | [optional] 
**precondition_steps** | [**WorkItemStepChangeViewModelArrayWorkItemChangedFieldViewModel**](WorkItemStepChangeViewModelArrayWorkItemChangedFieldViewModel.md) |  | [optional] 
**postcondition_steps** | [**WorkItemStepChangeViewModelArrayWorkItemChangedFieldViewModel**](WorkItemStepChangeViewModelArrayWorkItemChangedFieldViewModel.md) |  | [optional] 
**auto_tests** | [**AutoTestChangeViewModelArrayWorkItemChangedFieldViewModel**](AutoTestChangeViewModelArrayWorkItemChangedFieldViewModel.md) |  | [optional] 
**attachments** | [**AttachmentChangeViewModelArrayWorkItemChangedFieldViewModel**](AttachmentChangeViewModelArrayWorkItemChangedFieldViewModel.md) |  | [optional] 
**tags** | [**StringArrayWorkItemChangedFieldViewModel**](StringArrayWorkItemChangedFieldViewModel.md) |  | [optional] 
**links** | [**WorkItemLinkChangeViewModelArrayWorkItemChangedFieldViewModel**](WorkItemLinkChangeViewModelArrayWorkItemChangedFieldViewModel.md) |  | [optional] 
**global_id** | [**Int64WorkItemChangedFieldViewModel**](Int64WorkItemChangedFieldViewModel.md) |  | [optional] 
**version_number** | [**Int32WorkItemChangedFieldViewModel**](Int32WorkItemChangedFieldViewModel.md) |  | [optional] 
**entity_type_name** | [**StringWorkItemChangedFieldViewModel**](StringWorkItemChangedFieldViewModel.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


